==> nativescript-1.5.2.tgz: package/lib/common/mobile/local-to-device-path-data-factory.js <==
///<reference path="../.d.ts"/>
"use strict";
var helpers = require("../helpers");
var path = require("path");
var LocalToDevicePathData = (function () {
    function LocalToDevicePathData(fileName, localProjectRootPath, onDeviceFileName, deviceProjectRootPath) {
        this.fileName = fileName;
        this.localProjectRootPath = localProjectRootPath;
        this.onDeviceFileName = onDeviceFileName;
        this.deviceProjectRootPath = deviceProjectRootPath;
    }
    LocalToDevicePathData.prototype.getLocalPath = function () {
        return this.fileName;
    };
    LocalToDevicePathData.prototype.getDevicePath = function () {
        if (!this.devicePath) {
            var devicePath = path.join(this.deviceProjectRootPath, this.getRelativeToProjectBasePath());
            this.devicePath = helpers.fromWindowsRelativePathToUnix(devicePath);
        }
        return this.devicePath;
    };
    LocalToDevicePathData.prototype.getRelativeToProjectBasePath = function () {
        if (!this.relativeToProjectBasePath) {
            this.relativeToProjectBasePath = helpers.getRelativeToRootPath(this.localProjectRootPath, this.onDeviceFileName);
        }
        return this.relativeToProjectBasePath;
    };
    return LocalToDevicePathData;
})();
exports.LocalToDevicePathData = LocalToDevicePathData;
var LocalToDevicePathDataFactory = (function () {
    function LocalToDevicePathDataFactory() {
    }
    LocalToDevicePathDataFactory.prototype.create = function (fileName, localProjectRootPath, onDeviceFileName, deviceProjectRootPath) {
        return new LocalToDevicePathData(fileName, localProjectRootPath, onDeviceFileName, deviceProjectRootPath);
    };
    return LocalToDevicePathDataFactory;
})();
exports.LocalToDevicePathDataFactory = LocalToDevicePathDataFactory;
$injector.register("localToDevicePathDataFactory", LocalToDevicePathDataFactory);

==> nativescript-2.0.1.tgz: package/lib/common/mobile/local-to-device-path-data-factory.js <==
"use strict";
var helpers = require("../helpers");
var path = require("path");
var LocalToDevicePathData = (function () {
    function LocalToDevicePathData(filePath, localProjectRootPath, onDeviceFileName, deviceProjectRootPath) {
        this.filePath = filePath;
        this.localProjectRootPath = localProjectRootPath;
        this.onDeviceFileName = onDeviceFileName;
        this.deviceProjectRootPath = deviceProjectRootPath;
    }
    LocalToDevicePathData.prototype.getLocalPath = function () {
        return this.filePath;
    };
    LocalToDevicePathData.prototype.getDevicePath = function () {
        if (!this.devicePath) {
            var devicePath = path.join(this.deviceProjectRootPath, path.dirname(this.getRelativeToProjectBasePath()), this.onDeviceFileName);
            this.devicePath = helpers.fromWindowsRelativePathToUnix(devicePath);
        }
        return this.devicePath;
    };
    LocalToDevicePathData.prototype.getRelativeToProjectBasePath = function () {
        if (!this.relativeToProjectBasePath) {
            this.relativeToProjectBasePath = path.relative(this.localProjectRootPath, this.filePath);
        }
        return this.relativeToProjectBasePath;
    };
    return LocalToDevicePathData;
})();
var LocalToDevicePathDataFactory = (function () {
    function LocalToDevicePathDataFactory() {
    }
    LocalToDevicePathDataFactory.prototype.create = function (filePath, localProjectRootPath, onDeviceFileName, deviceProjectRootPath) {
        return new LocalToDevicePathData(filePath, localProjectRootPath, onDeviceFileName, deviceProjectRootPath);
    };
    return LocalToDevicePathDataFactory;
})();
exports.LocalToDevicePathDataFactory = LocalToDevicePathDataFactory;
$injector.register("localToDevicePathDataFactory", LocalToDevicePathDataFactory);
